@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 2.0.0 (2021-10-16)
+   Version: 2.0.1 (2021-10-25)
    Website: http://www.gingerblue.org/
 
  */
@@ -348,7 +348,7 @@ int main(int argc, char **argv)
 			   FALSE, FALSE, 5);
 	studio_label = gtk_button_new_with_label("Broadcasting");
 	studio_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(studio_entry), g_strconcat("http://", gtk_entry_get_text(GTK_ENTRY(computer_entry)), "/", NULL));
+	gtk_entry_set_text(GTK_ENTRY(studio_entry), g_strconcat("file://", gtk_entry_get_text(GTK_ENTRY(computer_entry)), "/", NULL));
 	g_signal_connect(G_OBJECT(studio_label), "clicked",
 			 G_CALLBACK(gb_assistant_apply),
 		         gtk_entry_get_text(GTK_ENTRY(studio_entry)));
@@ -526,8 +526,8 @@ int main(int argc, char **argv)
 	fprintf(xspf, "<playlist version=\"1\" xmlns=\"http://xspf.org/ns/0/\">\n");
 	fprintf(xspf, "<trackList>\n");
 	fprintf(xspf, "<track>\n");
-	fprintf(xspf, g_strconcat("<title>", gtk_entry_get_text(GTK_ENTRY(song_entry)), "</title>\n", NULL));
-	fprintf(xspf, g_strconcat("<location>file://", gtk_entry_get_text(GTK_ENTRY(computer_entry)), "/", gtk_entry_get_text(GTK_ENTRY(recording_entry)), "</location>\n", NULL));
+	fprintf(xspf, "%s", g_strconcat("<title>", gtk_entry_get_text(GTK_ENTRY(song_entry)), "</title>\n", NULL));
+	fprintf(xspf, "%s", g_strconcat("<location>file://", gtk_entry_get_text(GTK_ENTRY(computer_entry)), "/", gtk_entry_get_text(GTK_ENTRY(recording_entry)), "</location>\n", NULL));
 	fprintf(xspf, "</track>\n");
 	fprintf(xspf, "</trackList>\n");
 	fprintf(xspf, "</playlist>\n");
